@@ -183,7 +183,7 @@ if(.vector){
 	# check if some parameters are not to be put in the vector
 	if(!is.null(.args)){
 		.tmp <- match(.args,.un)
-		if(!is.na(.tmp)).un <- .un[-.tmp]
+		if(all(!is.na(.tmp))).un <- .un[-.tmp]
 		.par <- "alist(.p="
 		for(.j in 1:length(.args)){
 			.par <- paste(.par,",",collapse="")
@@ -394,7 +394,7 @@ if(length(.ex5a)>0)stop("index for nesting cannot be used in formulae with unkno
 #
 if(!is.null(.args)){
 	.tmp <- match(.args,.un)
-	if(!is.na(.tmp)).un <- .un[-.tmp]
+	if(all(!is.na(.tmp))).un <- .un[-.tmp]
 	.par <- "alist(.p="
 	for(.j in 1:length(.args)){
 		.par <- paste(.par,",",collapse="")
@@ -541,7 +541,7 @@ else {
 #
 if(!is.null(.args)){
 	.tmp <- match(.args,.un)
-	if(!is.na(.tmp)).un <- .un[-.tmp]
+	if(all(!is.na(.tmp))).un <- .un[-.tmp]
 	.par <- "alist(.p="
 	for(.j in 1:length(.args)){
 		.par <- paste(.par,",",collapse="")
@@ -687,7 +687,7 @@ else {
 #
 if(!is.null(.args)){
 	.tmp <- match(.args,.un)
-	if(!is.na(.tmp)).un <- .un[-.tmp]
+	if(all(!is.na(.tmp))).un <- .un[-.tmp]
 	.par <- "alist(.p="
 	for(.j in 1:length(.args)){
 		.par <- paste(.par,",",collapse="")
@@ -820,7 +820,7 @@ if(length(.ex1a)>0)for(.j in 1:length(.ex1a))if(is.factor(.envir[,.ex1a[.j]]))
 #
 if(!is.null(.args)){
 	.tmp <- match(.args,.un)
-	if(!is.na(.tmp)).un <- .un[-.tmp]
+	if(all(!is.na(.tmp))).un <- .un[-.tmp]
 	.par <- "alist(.p="
 	for(.j in 1:length(.args)){
 		.par <- paste(.par,",",collapse="")
@@ -946,7 +946,7 @@ if(length(.un0)>0){
 		for(.k in 1:length(.un1))
 			if(length(grep(.un1[.k],.un0))>0)
 				.tmp <- c(.tmp,grep(.un1[.k],.un0))
-		.un <- c(.un,unique(.un0[-.tmp]))}
+		.un <- c(.un,unique(if(!is.null(.tmp)).un0[-.tmp]else .un0))}
 	else .un <- c(.un,unique(.un0))}
 #
 # create the new function that evaluates its model attribute
@@ -1098,7 +1098,7 @@ if(length(.un0)>0){
 		for(.k in 1:length(.un1))
 			if(length(grep(.un1[.k],.un0))>0)
 				.tmp <- c(.tmp,grep(.un1[.k],.un0))
-		.un <- c(.un,unique(.un0[-.tmp]))}
+		.un <- c(.un,unique(if(!is.null(.tmp)).un0[-.tmp]else .un0))}
 	else .un <- c(.un,unique(.un0))}
 #
 # create the new function that evaluates its model attribute
@@ -1222,7 +1222,7 @@ if(length(.un0)>0){
 		for(.k in 1:length(.un1))
 			if(length(grep(.un1[.k],.un0))>0)
 				.tmp <- c(.tmp,grep(.un1[.k],.un0))
-		.un <- c(.un,unique(.un0[-.tmp]))}
+		.un <- c(.un,unique(if(!is.null(.tmp)).un0[-.tmp]else .un0))}
 	else .un <- c(.un,unique(.un0))}
 #
 # create the new function that evaluates its model attribute
@@ -1345,7 +1345,7 @@ if(length(.un0)>0){
 		for(.k in 1:length(.un1))
 			if(length(grep(.un1[.k],.un0))>0)
 				.tmp <- c(.tmp,grep(.un1[.k],.un0))
-		.un <- c(.un,unique(.un0[-.tmp]))}
+		.un <- c(.un,unique(if(!is.null(.tmp)).un0[-.tmp]else .un0))}
 	else .un <- c(.un,unique(.un0))}
 #
 # create the new function that evaluates its model attribute
@@ -1459,7 +1459,7 @@ if(length(.un0)>0){
 		for(.k in 1:length(.un1))
 			if(length(grep(.un1[.k],.un0))>0)
 				.tmp <- c(.tmp,grep(.un1[.k],.un0))
-		.un <- c(.un,unique(.un0[-.tmp]))}
+		.un <- c(.un,unique(if(!is.null(.tmp)).un0[-.tmp]else .un0))}
 	else .un <- c(.un,unique(.un0))}
 #
 # create the new function that evaluates its model attribute
