@@ -828,9 +828,8 @@ else if(is.data.frame(ccov)){
 	if(!dataframe){
 	# if a dataframe supplied, but should not be stored as one
                 rm(names)
-                tmp <- NULL
+                units2 <- mt <- tmp3 <- tmp <- NULL
                 j <- 0
-		units2 <- NULL
                 for(i in ccov){
                 	j <- j+1
                 	if(is.vector(i,mode="numeric")){
@@ -850,7 +849,7 @@ else if(is.data.frame(ccov)){
                 	tmp <- cbind(tmp,tmp2)}
 		units <- units2
                 ccov <- tmp
-                rm(tmp,tmp2,mt)}}
+                rm(tmp,tmp2,tmp3,mt)}}
 else if(!is.matrix(ccov))
 	stop("Inter-unit (time-constant) covariates must be a vector, matrix, dataframe, or model formula")
 if(is.null(colnames(ccov))){
@@ -993,7 +992,7 @@ else if(is.list(tvcov)&&!is.data.frame(tvcov)){
 			else tvcv <- rbind(tvcv,i)}
 		if(is.character(tvcv)||!dataframe){
 		# if necessary, transform to indicator matrix
-			tmp <- tmp2 <- NULL
+			tmp <- tmp2 <- mt <- NULL
 			for(i in 1:ncols){
 				if(is.numeric(tvcv[,i])){
 					tmp <- cbind(tmp,tvcv[,i])
